@@ -64,7 +64,7 @@ class Drive(NetBoxModel):
     def device_name(self):
         return f"/dev/sd{chr(ord('`') + int(self.identifier[-1]))}"
 
-    def physicalvolumes_count(self):
+    def physicalvolumes_in_drive_count(self):
         return PhysicalVolume.objects.filter(drive=self).count()
 
 
@@ -132,7 +132,6 @@ class Partition(NetBoxModel):
         return PhysicalVolume.objects.filter(partition=self).count()
 
 
-# In this example, a Reporter (vg) can be associated with many Article (pv) objects, but an Article (pv) can only have one Reporter (vg) object:
 class VolumeGroup(NetBoxModel):
     vg_name = models.CharField(
         max_length=255,
@@ -174,11 +173,6 @@ class PhysicalVolume(NetBoxModel):
         on_delete=models.CASCADE,
         related_name='volumegroup_physicalvolume',
     )
-    drive = models.ForeignKey(
-        Drive,
-        on_delete=models.CASCADE,
-        related_name='drive_physicalvolume',
-    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -188,13 +182,12 @@ class PhysicalVolume(NetBoxModel):
         "partition",
         "pv_name",
         "vg",
-        "drive",
         "description",
     ]
 
-    #prerequisite_models = (
-    #    'netbox_storage.VolumeGroup',
-    #)
+    # prerequisite_models = (
+    #     'netbox_storage.VolumeGroup',
+    # )
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
